@@ -43,8 +43,6 @@ ssl_cert_parameter_map = {
 }
 
 
-
-
 def _parse_timestamp(value):
     if value:
         match = _TIMESTAMP_PATTERN.match(value)
@@ -166,6 +164,9 @@ class Connection(object):
         self._client.clear(query_id)
         self._transport.close()
 
+    def clear(self, query_id):
+        self._client.clear(query_id)
+
     def reopen(self):
         self._transport.close()
         self._transport.open()
@@ -193,6 +194,7 @@ class Cursor(common.DBAPICursor):
     visible by other cursors or connections.
     """
     rows_count = 0
+
     def __init__(self, connection, arraysize=1000):
         super(Cursor, self).__init__()
         self._arraysize = arraysize
@@ -202,6 +204,7 @@ class Cursor(common.DBAPICursor):
         self._description = None
         self._query_id = None
         self._batch = list()
+        self._rowcount = 0
 
     def _reset_state(self):
         """Reset state about the previous query in preparation for running another query"""
@@ -259,6 +262,10 @@ class Cursor(common.DBAPICursor):
         self.connection.close(self._query_id)
         pass
 
+    def clear(self):
+        """Clears the tmp data"""
+        self.connection.clear(self._query_id)
+
     def execute(self, operation, parameters=None, **kwargs):
         """Prepare and execute a database operation (query or command).
         Return values are not defined.
@@ -276,10 +283,13 @@ class Cursor(common.DBAPICursor):
         _logger.info("getting result metadata")
         buffer = client.getResultMetadata(self._query_id)
         buffer = BytesIO(buffer)
-        self._query_columns_description = get_query_columns_info(buffer)
+        self._rowcount, self._query_columns_description = get_query_columns_info(buffer)
         _logger.info("finished populating metadata")
         return
 
+    def rowcount(self):
+        return self._rowcount
+
     def cancel(self):
         """Uniphi does not support cancelling of queries as yet"""
         pass
@@ -384,7 +394,7 @@ if __name__ == '__main__':
                          port=9000,
                          scheme="e6xdb",
                          username="admin",
-                         database="s3a://e6-tpcds/parquet100gb_128/",
+                         database="tpc_10gb",
                          auth=None,
                          configuration=None,
                          kerberos_service_name=None,
@@ -393,16 +403,19 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("SELECT c_first_name FROM store_returns AS sr, customer AS c WHERE c.c_customer_sk = sr.sr_customer_sk AND c.c_first_name = 'Susan' ORDER BY sr_returned_date_sk;")
+    cursor.execute("select * from call_center;")
     bdata = cursor.fetchone()
     try:
         while len(bdata) > 0:
+            print(bdata)
             print(len(bdata))
             bdata = cursor.fetchone()
-            list(islice(iter(bdata, None), 10000))
+            # list(islice(iter(bdata, None), 10000))
     except Exception as e:
         cursor.close()
 
+    cursor.clear()
+
 #
 # Type Objects and Constructors
 #
